RA

Fork of RA8875 by David Smart

Revision:
50:2c4f474a2453
Parent:
45:679c2fb8480c
Child:
53:86d24b9480b9
--- a/RA8875.h	Mon Mar 10 23:53:40 2014 +0000
+++ b/RA8875.h	Sat Mar 15 17:35:51 2014 +0000
@@ -128,7 +128,7 @@
     // at startup, and not at runtime.
     //~RA8875();
     
     /// Select the layer for subsequent commands.
     ///
     /// If the screen configuration is 480 x 272, or if it is 800 x 480 
     /// and 8-bit color, the the display supports two layers, which can 
@@ -144,7 +144,7 @@
     ///     to in the user manual).
     /// @returns success/failure code. @see RetCode_t.
     ///
-    RetCode_t SelectLayer(uint16_t layer);
+    RetCode_t SelectDrawingLayer(uint16_t layer);
     
     /// Set the Layer presentation mode.
     ///
@@ -128,7 +128,7 @@
     //~RA8875();
     
-    /// Select the layer for subsequent commands.
+    /// Select the drawing layer for subsequent commands.
     ///
     /// If the screen configuration is 480 x 272, or if it is 800 x 480 